# 3D Datasets

## `haase_mrt.tif`

Author: Robert Haase
URL: https://data.niaid.nih.gov/resources?id=zenodo_5090507
Licensed under CC BY 4.0.

## `fused.tif`

Author: Mariia Golden
Licensed under Licensed under CC BY-NC-SA 4.0.

The image has been down-scaled and the border around the image data has been
removed.

## `illumination.tif`

Author: Mariia Golden
Licensed under Licensed under CC BY-NC-SA 4.0.
